From ok@artecdesign.ee Thu Aug  4 06:58:34 2005
Date: Thu, 4 Aug 2005 16:52:31 +0300 (EEST)
From: Olav Kongas <ok@artecdesign.ee>
To: Greg KH <greg@kroah.com>
Subject: USB: isp116x-hcd: support only per-port power switching
Message-ID: <Pine.LNX.4.63.0508041648360.2726@pcx>


The isp116x chip will now always be in per-port power switching mode. Remove
conf options to set any other mode.

Signed-off-by: Olav Kongas <ok@artecdesign.ee>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/usb/host/isp116x-hcd.c |    9 ++++-----
 include/linux/usb_isp116x.h    |    5 -----
 2 files changed, 4 insertions(+), 10 deletions(-)

--- gregkh-2.6.orig/drivers/usb/host/isp116x-hcd.c	2005-08-08 16:01:39.000000000 -0700
+++ gregkh-2.6/drivers/usb/host/isp116x-hcd.c	2005-08-08 16:01:40.000000000 -0700
@@ -1581,11 +1581,10 @@
 
 	/* ----- Root hub conf */
 	val = (25 << 24) & RH_A_POTPGT;
-	/* AN10003_1.pdf recommends NPS to be always 1 */
-	if (board->no_power_switching)
-		val |= RH_A_NPS;
-	if (board->power_switching_mode)
-		val |= RH_A_PSM;
+	/* AN10003_1.pdf recommends RH_A_NPS (no power switching) to
+	   be always set. Yet, instead, we request individual port
+	   power switching. */
+	val |= RH_A_PSM;
 	isp116x_write_reg32(isp116x, HCRHDESCA, val);
 	isp116x->rhdesca = isp116x_read_reg32(isp116x, HCRHDESCA);
 
--- gregkh-2.6.orig/include/linux/usb_isp116x.h	2005-08-08 16:01:39.000000000 -0700
+++ gregkh-2.6/include/linux/usb_isp116x.h	2005-08-08 16:01:40.000000000 -0700
@@ -19,11 +19,6 @@
 	   prevents stopping internal clock, increasing
 	   thereby power consumption in suspended state. */
 	unsigned remote_wakeup_enable:1;
-	/* Switch or not to switch (keep always powered) */
-	unsigned no_power_switching:1;
-	/* Ganged port power switching (0) or individual port
-	   power switching (1) */
-	unsigned power_switching_mode:1;
 	/* Hardware reset set/clear. If implemented, this function must:
 	   if set == 0,   deassert chip's HW reset pin
 	   otherwise,     assert chip's HW reset pin       */
